DUNDER_BUILDINS_THAT_RETURNS_BOOL = {
    'contains',
    'enter',
    'exit',
    'bool',
    'aenter',
    'aexit',
    'eq',
    'ge',
    'gt',
    'le',
    'ne',
    'lt',
}

BLACKLISTED_WORDS_IN_FUNCTIONS_NAMES = {
    'and',
}

PURE_VERBS = {
    'calculate',
    'extract',
    'analyze',
    'create',
    'initialize',
    'configure',
    'parse',
    'render',
    'iter',
    'validate',
    'walk',
    'find',
    'search',
    'match',
    'morph',
    'compose',
    'prepare',
    'extract',
    'generate',
    'initialize',
    'filter',
    'map',
    'aggregate',
    'export',
    'import',
    'normalize',
}

VERBS = PURE_VERBS.union({
    'abbreviate',
    'abort',
    'accelerate',
    'accentuate',
    'accept',
    'access',
    'according',
    'account',
    'accumulate',
    'achieve',
    'acknowledge',
    'acquire',
    'activate',
    'adapt',
    'add',
    'adde',
    'adds',
    'adjust',
    'adopt',
    'advance',
    'aggregatу',
    'alert',
    'allocate',
    'allow',
    'alter',
    'analyse',
    'annotate',
    'announce',
    'anonymize',
    'append',
    'apply',
    'approve',
    'archive',
    'arrive',
    'assig',
    'assign',
    'assume',
    'assumme',
    'atomize',
    'attach',
    'attempt',
    'auhtorize',
    'authenticate',
    'authorize',
    'autoescape',
    'autogenerate',
    'autoscale',
    'average',
    'avoid',
    'award',
    'bake',
    'balance',
    'ban',
    'became',
    'begin',
    'believe',
    'binarize',
    'bind',
    'blacklist',
    'block',
    'boost',
    'boot',
    'bound',
    'break',
    'bundle',
    'buy',
    'cache',
    'calibrate',
    'call',
    'cancel',
    'cancell',
    'capture',
    'case',
    'cast',
    'catch',
    'categorize',
    'chain',
    'change',
    'check',
    'chek',
    'choose',
    'chunk',
    'clear',
    'clean',
    'climb',
    'clone',
    'close',
    'clusterize',
    'coerce',
    'collapse',
    'collect',
    'colorize',
    'combine',
    'come',
    'comes',
    'comment',
    'commit',
    'compare',
    'compile',
    'complete',
    'compress',
    'compute',
    'concatenate',
    'conclude',
    'condition',
    'confirm',
    'conflict',
    'conform',
    'confuse',
    'connect',
    'consent',
    'consider',
    'construct',
    'consul',
    'consume',
    'contain',
    'contest',
    'contrast',
    'control',
    'controll',
    'converge',
    'convert',
    'coordinate',
    'copy',
    'correct',
    'corrupt',
    'count',
    'cover',
    'crash',
    'crawl',
    'crop',
    'cros',
    'curry',
    'customize',
    'daemonize',
    'damage',
    'deactivate',
    'deauthorize',
    'debounce',
    'debug',
    'declare',
    'decline',
    'decode',
    'decompress',
    'deconstruct',
    'decorate',
    'decoratore',
    'decrease',
    'decrypt',
    'deduplicate',
    'defer',
    'define',
    'delegate',
    'delete',
    'delimit',
    'deliver',
    'delocalize',
    'denormalize',
    'deny',
    'deprecate',
    'derive',
    'deserialize',
    'destroy',
    'detach',
    'detect',
    'detecte',
    'determine',
    'detokenize',
    'develop',
    'differ',
    'digitize',
    'disablу',
    'disappeare',
    'disarm',
    'disassemble',
    'discard',
    'disconnect',
    'discount',
    'discover',
    'discretize',
    'dismiss',
    'dispatch',
    'dispatche',
    'display',
    'distribute',
    'diverge',
    'do',
    'documented',
    'does',
    'dominate',
    'double',
    'download',
    'downsample',
    'drain',
    'draw',
    'drop',
    'dump',
    'duplicate',
    'edit',
    'elapse',
    'elide',
    'embed',
    'empty',
    'emulate',
    'enable',
    'enclose',
    'encode',
    'encrypt',
    'end',
    'enforce',
    'enroll',
    'ensure',
    'enter',
    'enumerate',
    'equalize',
    'escalate',
    'escape',
    'establish',
    'evaluate',
    'exceed',
    'exchange',
    'exclude',
    'execute',
    'exhaust',
    'exist',
    'exit',
    'expand',
    'expect',
    'expire',
    'explain',
    'explode',
    'explore',
    'expose',
    'extend',
    'factorize',
    'fade',
    'fail',
    'faile',
    'falsify',
    'fetch',
    'fill',
    'finalize',
    'fingerprint',
    'finish',
    'fire',
    'fix',
    'flip',
    'flipp',
    'flush',
    'focuse',
    'fold',
    'follow',
    'forbid',
    'force',
    'forgive',
    'fork',
    'form',
    'format',
    'forward',
    'frame',
    'free',
    'fulfill',
    'get',
    'gets',
    'getting',
    'give',
    'gives',
    'go',
    'greet',
    'grow',
    'guarde',
    'handle',
    'hang',
    'hold',
    'humanify',
    'identify',
    'ignore',
    'implement',
    'imply',
    'improve',
    'improvу',
    'include',
    'increas',
    'increase',
    'increment',
    'infect',
    'infer',
    'inform',
    'inherit',
    'init',
    'initiate',
    'inject',
    'insert',
    'inspect',
    'install',
    'installe',
    'instantiate',
    'instrument',
    'integrate',
    'interpolate',
    'interpret',
    'interrupt',
    'intilialize',
    'introspect',
    'invalidate',
    'invert',
    'invite',
    'invoke',
    'iterate',
    'join',
    'keep',
    'keyring',
    'kill',
    'know',
    'label',
    'land',
    'launch',
    'lead',
    'learn',
    'leave',
    'let',
    'limit',
    'link',
    'list',
    'listen',
    'load',
    'localize',
    'lock',
    'log',
    'look',
    'lose',
    'lower',
    'maintain',
    'make',
    'manage',
    'mangl',
    'mark',
    'mask',
    'materialize',
    'maximizу',
    'measure',
    'memcache',
    'memoize',
    'mention',
    'merge',
    'migrate',
    'minify',
    'minimize',
    'minoring',
    'mirror',
    'misbehave',
    'mismatch',
    'miss',
    'misspell',
    'mix',
    'mocking',
    'modify',
    'mold',
    'monitore',
    'move',
    'mutate',
    'mute',
    'need',
    'negotiate',
    'nest',
    'normalise',
    'note',
    'notify',
    'observe',
    'obtain',
    'occupy',
    'offer',
    'omit',
    'onboard',
    'open',
    'optimise',
    'optimize',
    'organise',
    'organize',
    'orient',
    'orthonormalize',
    'outdate',
    'overlap',
    'overload',
    'override',
    'overwrite',
    'pack',
    'pad',
    'paginate',
    'parallelize',
    'parameterize',
    'parametrize',
    'participate',
    'pass',
    'patch',
    'patchin',
    'pause',
    'perform',
    'permit',
    'persist',
    'personalize',
    'pick',
    'pickle',
    'pin',
    'ping',
    'place',
    'play',
    'plot',
    'polygonize',
    'populate',
    'post',
    'postprocess',
    'precompute',
    'predefine',
    'predict',
    'prefetch',
    'prefill',
    'prepend',
    'prepopulate',
    'preprocess',
    'preserve',
    'press',
    'prevent',
    'prime',
    'print',
    'process',
    'produce',
    'profile',
    'profilr',
    'prohibit',
    'promote',
    'propagate',
    'propogate',
    'propose',
    'protect',
    'provide',
    'provision',
    'proxy',
    'prune',
    'publish',
    'pull',
    'push',
    'qualify',
    'quantify',
    'quantize',
    'quarantine',
    'quote',
    'raise',
    'randomize',
    'read',
    'rearrange',
    'receive',
    'recognize',
    'reconnect',
    'reconstruct',
    'record',
    'recover',
    'recreat',
    'redefine',
    'redirect',
    'reduce',
    'refactor',
    'reference',
    'refine',
    'refit',
    'reflect',
    'refresh',
    'refuse',
    'register',
    'regularize',
    'rehash',
    'reject',
    'relabel',
    'relearn',
    'release',
    'reload',
    'rely',
    'remap',
    'remember',
    'remove',
    'rename',
    'reoccurre',
    'reopen',
    'reorder',
    'reorganize',
    'reparameterize',
    'repeat',
    'replace',
    'replicate',
    'report',
    'represent',
    'reprocess',
    'reproduce',
    'require',
    'resample',
    'resave',
    'rescale',
    'reschedule',
    'rescue',
    'reserve',
    'reset',
    'reshape',
    'resize',
    'resolve',
    'respawn',
    'restart',
    'restore',
    'restrict',
    'resume',
    'resurrect',
    'retokenize',
    'retrieve',
    'retry',
    'reuse',
    'reverse',
    'revert',
    'review',
    'revise',
    'revive',
    'revoke',
    'rewrite',
    'roll',
    'rotate',
    'round',
    'routу',
    'run',
    'salt',
    'sample',
    'sanitize',
    'satisfy',
    'save',
    'scaffold',
    'scale',
    'scan',
    'scatter',
    'schedule',
    'scope',
    'score',
    'scrape',
    'scroll',
    'secure',
    'seed',
    'seek',
    'select',
    'send',
    'separate',
    'serialize',
    'serve',
    'set',
    'shape',
    'share',
    'shift',
    'show',
    'shred',
    'shrink',
    'shuffle',
    'sign',
    'signal',
    'simplify',
    'skip',
    'sleep',
    'slice',
    'slide',
    'smooth',
    'solarize',
    'sort',
    'source',
    'spawn',
    'specialise',
    'specialize',
    'specify',
    'spell',
    'spool',
    'spread',
    'square',
    'squash',
    'stack',
    'stage',
    'standardize',
    'start',
    'step',
    'stop',
    'store',
    'stream',
    'stride',
    'stringify',
    'stripe',
    'stylize',
    'subclass',
    'submit',
    'subsample',
    'subscribe',
    'suggest',
    'summarize',
    'supply',
    'support',
    'suppres',
    'suppress',
    'suspect',
    'suspend',
    'swap',
    'swapp',
    'swing',
    'switch',
    'sync',
    'synchronize',
    'synthesize',
    'take',
    'tamper',
    'target',
    'tel',
    'templatize',
    'terminate',
    'test',
    'throw',
    'tokenize',
    'touch',
    'trace',
    'track',
    'train',
    'transcode',
    'transfer',
    'transform',
    'translate',
    'transmit',
    'transpose',
    'trap',
    'traverse',
    'treat',
    'trigger',
    'trim',
    'trimm',
    'truncate',
    'trust',
    'try',
    'turn',
    'typecheck',
    'undo',
    'unlink',
    'unlock',
    'unpad',
    'unpin',
    'unquote',
    'unregister',
    'update',
    'upload',
    'upsample',
    'use',
    'vaulted',
    'vectorize',
    'verify',
    'version',
    'visit',
    'wait',
    'warn',
    'watch',
    'were',
    'whitelist',
    'work',
    'wrapp',
    'write',
    'yield',
    'zoom',
})
